% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Palaeodose_Computation.R
\name{Palaeodose_Computation}
\alias{Palaeodose_Computation}
\title{Bayesian analysis for the palaeodose estimation of various samples}
\usage{
Palaeodose_Computation(DATA, SampleNames, Nb_sample, BinPerSample = rep(1,
  Nb_sample), SavePdf = FALSE, OutputFileName = c("MCMCplot"),
  OutputFilePath = c(""), SaveEstimates = FALSE,
  OutputTableName = c("DATA"), OutputTablePath = c(""), LIN_fit = TRUE,
  Origin_fit = FALSE, distribution = c("cauchy"), Iter = 50000, t = 5,
  Nb_chaines = 3)
}
\arguments{
\item{DATA}{list of objects: LT, sLT, ITimes, dLab, ddot_env, regDose, J, K, Nb_measurement,
provided by \code{\link{Generate_DataFile}} or \code{\link{Generate_DataFile_MG}}.
\code{DATA} contains information for more than one sample.}

\item{SampleNames}{character vector: names of sample. The length of this vector is equal to \code{Nb_sample}.}

\item{Nb_sample}{integer: number of samples.}

\item{BinPerSample}{integer vector (with default): vector with the number of BIN files per sample.
The length of this vector is equal to \code{Nb_sample}.
\code{BinPerSample}[i] correponds to the number of BIN files for the sample whose number ID is equal to \code{i}.
For more information to fill this vector, we refer to detatils in \code{\link{Generate_DataFile}} or \code{\link{Generate_DataFile_MG}}.}

\item{SavePdf}{boolean (with default): if TRUE save graph in pdf file named \code{OutputFileName} in folder \code{OutputFilePath}.}

\item{OutputFileName}{character (with default): name of the pdf files that will be generated by the function.}

\item{OutputFilePath}{character (with default): path to the pdf files that will be generated by the function.}

\item{SaveEstimates}{boolean (with default): if TRUE save Bayes estimates and credible interval at level 68% and 95%,
in a csv table named \code{OutputFileName} in folder \code{OutputFilePath}.}

\item{OutputTableName}{character (with default): name of the table that will be generated by the function if \code{SaveEstimates}=TRUE.}

\item{OutputTablePath}{character (with default): path to the table that will be generated by the function if \code{SaveEstimates}=TRUE.}

\item{LIN_fit}{logical (with default): if TRUE (default) allows a linear component,
on top of the (default) saturating exponential curve, for the fitting of dose response curves.
Please see details for more informations on the proposed dose response curves.}

\item{Origin_fit}{logical (with default): if TRUE, forces the dose response curves to pass through the origin.
Please see details for more informations on the proposed growth curves.}

\item{distribution}{character (with default): type of distribution that defines
how individual equivalent dose values are distributed around the palaeodose.
Allowed inputs are \bold{"cauchy"}, \bold{"gaussian"}, \bold{"lognormal_A"} and \bold{"lognormal_M"}.}

\item{Iter}{integer (with default): number of iterations for the MCMC computation (for more information see \code{\link{jags.model}}).}

\item{t}{integer (with default): 1 every \code{t} iterations of the MCMC is considered for sampling the posterior distribution
(for more information see \code{\link{jags.model}}).}

\item{Nb_chaines}{integer (with default): number of independent chains for the model (for more information see \code{\link{jags.model}}).}
}
\value{
\bold{NUMERICAL OUTPUT}\cr

\enumerate{
 \item \bold{A list containing the following objects:}
 \itemize{
  \item \bold{Sampling} that corresponds to a sample of the posterior distributions
 of palaeodose and equivalent dose dispersion parameters (both in Gy).
  \item \bold{Model_GrowthCurve}, stating which dose response fitting option was chosen;
  \item \bold{Distribution}, stating which distribution was chosen to model the dispersion of
 individual equivalent dose values around the palaeodose of the sample.
 }
 \item\bold{The Gelman and Rudin test of convergency}: prints the result of the Gelman and Rudin test of convergency for palaeodose and equivalent dose dispersion parameters for each sample.
A result close to one is expected.\cr
In addition, the user must visually assess the convergency of the trajectories by looking at the pdf file
generated by the function (see \bold{PLOT OUTPUT} for more informations).\cr
If both convergencies (Gelman and Rudin test and plot checking) are satisfactory,
the user can consider the printed estimates as valid. Otherwise, the user may try increasing the number of MCMC interations
(\code{Iter}) to reach convergency.
 \item\bold{Credible intervals and Bayes estimates}: prints the Bayes esitmates, the credible intervals at 95\% and 68\% for
the palaeodose and equivalent dose dispersion parameters for each sample.
}

\bold{PLOT OUTPUT}

\enumerate{
 \item\bold{MCMC trajectories}
A graph with the MCMC trajectories and posterior distributions of the palaeodose and equivalent dose dispersion parameters
is displayed, there is one page per sample. \cr
The first line of the figure correponds to the palaeodose parameter and the second to the equivalent dose dispersion parameter.
On each line, the plot on the left represents the MCMC trajectories, and the one on the right the posterior distribution of the parameter.
 \item \bold{Summary of palaeodose estimates}: plot credible intervals and Bayes estimate of each sample palaeodose on a same graph.
}
To give result in a publication, we recommend to give the Bayes estimate of the parameters as well as the credible interval at 95\% or 68\%.
}
\description{
This function computes the palaeodose (in Gy) of one or various samples according to the model developed in Combes et al (2015),
based on an output of \code{\link{Generate_DataFile}} or \code{\link{Generate_DataFile_MG}}
or both of them using \code{\link{Concat_DataFile}}.\cr
Samples, for which data is avalilable in several BIN files, can be analysed.\cr
Single-grain or Multi-grain OSL measurements can be analysed simultaneouly.
}
\details{
\bold{** Option on growth curves **}

As for \code{\link{Age_Computation}} and \code{\link{AgeS_Computation}}, the user can choose from 4 dose response curves:
\itemize{
  \item \bold{Saturating exponential plus linear growth} (\code{PalaeodosesMultiBF_EXPLIN}):

  for all \code{x} in IR+, \code{f(x)=a(1-exp(-x/b))+cx+d}; select
  \itemize{
    \item \code{LIN_fit=TRUE}
    \item \code{Origin_fit=FALSE}
  }
  \item \bold{Saturating exponential growth} (\code{PalaeodosesMultiBF_EXP}):

  for all \code{x} in IR+, \code{f(x)=a(1-exp(-x/b))+d}; select
  \itemize{
    \item \code{LIN_fit=FALSE}
    \item \code{Origin_fit=FALSE}
  }
  \item \bold{Saturating exponential plus linear growth and fitting through the origin} (\code{PalaeodosesMultiBF_EXPLINZO}):

  for all \code{x} in IR+, \code{f(x)=a(1-exp(-x/b))+cx}; select
  \itemize{
    \item \code{LIN_fit=TRUE}
    \item \code{Origin_fit=TRUE}
  }
  \item \bold{Saturating exponential growth and fitting through the origin} (\code{PalaeodosesMultiBF_EXPZO}):

  for all \code{x} in IR+, \code{f(x)=a(1-exp(-x/b))}; select
  \itemize{
    \item \code{LIN_fit=FALSE}
    \item \code{Origin_fit=TRUE}
  }
}

\bold{** Option on equivalent dose distribution around the palaeodose **}

The use can choose between :
\itemize{
  \item \code{cauchy}: a Cauchy distribution with location parameter equal to the palaeodose of the sample
  \item \code{gaussian}: a Gaussian distribution with mean equal to the palaeodose of the sample
  \item \code{lognormal_A}: a log-normal distribution with mean or \bold{A}verage equal to the palaeodose of the sample
  \item \code{lognormal_M}: a log-normal distribution with \bold{M}edian equal to the palaeodose of the sample
}
}
\examples{
## Load data
data(DATA1,envir = environment())
## Palaeodose computation of samples GDB3
P=Palaeodose_Computation(DATA=DATA1,Nb_sample=1,SampleNames=c("GDB5"),Iter=100)

}
\references{
Combes, B., Philippe, A., Lanos, P., Mercier, N., Tribolo, C., Guerin, G., Guibert, P., Lahaye, C., 2015.
A Bayesian central equivalent dose model for optically stimulated luminescence dating.
Quaternary Geochronology 28, 62-70. doi:10.1016/j.quageo.2015.04.001
}
\seealso{
\code{\link{Generate_DataFile}}, \code{\link{Generate_DataFile_MG}}, \code{\link{Concat_DataFile}},
\code{\link{rjags}}, \code{\link{MCMC_plot}},
\code{\link{Age_Computation}}, \code{\link{AgeS_Computation}}
}
\author{
Claire Christophe, Anne Philippe, Guillaume Guerin
}
